# Generated by the protocol buffer compiler (protoc-perl) DO NOT EDIT!
# source: /var/folders/_z/f1y684ms225_w0sk8sjlrzbw0000gn/T/PpcoUgJ0AY



use strict;
use warnings;

use Google::ProtocolBuffers;
{
    unless (Mesos::Volume::Mode->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::Volume::Mode',
            [
               ['RW', 1],
               ['RO', 2],

            ]
        );
    }
    
    unless (Mesos::Value::Type->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::Value::Type',
            [
               ['SCALAR', 0],
               ['RANGES', 1],
               ['SET', 2],
               ['TEXT', 3],

            ]
        );
    }
    
    unless (Mesos::Status->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::Status',
            [
               ['DRIVER_NOT_STARTED', 1],
               ['DRIVER_RUNNING', 2],
               ['DRIVER_ABORTED', 3],
               ['DRIVER_STOPPED', 4],

            ]
        );
    }
    
    unless (Mesos::ContainerInfo::Type->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::ContainerInfo::Type',
            [
               ['DOCKER', 1],

            ]
        );
    }
    
    unless (Mesos::ACL::Entity::Type->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::ACL::Entity::Type',
            [
               ['SOME', 0],
               ['ANY', 1],
               ['NONE', 2],

            ]
        );
    }
    
    unless (Mesos::TaskState->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_enum(
            'Mesos::TaskState',
            [
               ['TASK_STAGING', 6],
               ['TASK_STARTING', 0],
               ['TASK_RUNNING', 1],
               ['TASK_FINISHED', 2],
               ['TASK_FAILED', 3],
               ['TASK_KILLED', 4],
               ['TASK_LOST', 5],

            ]
        );
    }
    
    unless (Mesos::ContainerID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ContainerID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::CommandInfo::URI->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::CommandInfo::URI',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'executable', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'extract', 3, 1
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::TaskInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::TaskInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::TaskID', 
                    'task_id', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::SlaveID', 
                    'slave_id', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Resource', 
                    'resources', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ExecutorInfo', 
                    'executor', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BYTES(), 
                    'data', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::CommandInfo', 
                    'command', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::HealthCheck', 
                    'health_check', 8, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ContainerInfo', 
                    'container', 9, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value::Set->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value::Set',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'item', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ExecutorID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ExecutorID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::FrameworkInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::FrameworkInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'user', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::FrameworkID', 
                    'id', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'failover_timeout', 4, 0.0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'checkpoint', 5, 0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'role', 6, "*"
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'hostname', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'principal', 8, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ContainerInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ContainerInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ContainerInfo::Type', 
                    'type', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Volume', 
                    'volumes', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ContainerInfo::DockerInfo', 
                    'docker', 3, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACL::ShutdownFramework->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACL::ShutdownFramework',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'principals', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'framework_principals', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Environment::Variable->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Environment::Variable',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::TaskID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::TaskID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value::Scalar->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value::Scalar',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::RateLimit->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::RateLimit',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'qps', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'principal', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'capacity', 3, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACL->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACL',
            [

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ResourceStatistics->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ResourceStatistics',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'timestamp', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'cpus_user_time_secs', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'cpus_system_time_secs', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'cpus_limit', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'mem_rss_bytes', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'mem_limit_bytes', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'cpus_nr_periods', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'cpus_nr_throttled', 8, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'cpus_throttled_time_secs', 9, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'mem_file_bytes', 10, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'mem_anon_bytes', 11, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'mem_mapped_file_bytes', 12, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::PerfStatistics', 
                    'perf', 13, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_rx_packets', 14, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_rx_bytes', 15, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_rx_errors', 16, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_rx_dropped', 17, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_tx_packets', 18, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_tx_bytes', 19, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_tx_errors', 20, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'net_tx_dropped', 21, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Credentials->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Credentials',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Credential', 
                    'credentials', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::RateLimits->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::RateLimits',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::RateLimit', 
                    'limits', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'aggregate_default_qps', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'aggregate_default_capacity', 3, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::CommandInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::CommandInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::CommandInfo::URI', 
                    'uris', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Environment', 
                    'environment', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::CommandInfo::ContainerInfo', 
                    'container', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'user', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'shell', 6, 1
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'arguments', 7, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACL::RegisterFramework->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACL::RegisterFramework',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'principals', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'roles', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::TaskStatus->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::TaskStatus',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::TaskID', 
                    'task_id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::TaskState', 
                    'state', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BYTES(), 
                    'data', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'message', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::SlaveID', 
                    'slave_id', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'timestamp', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ExecutorID', 
                    'executor_id', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'healthy', 8, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::FrameworkID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::FrameworkID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Credential->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Credential',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'principal', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BYTES(), 
                    'secret', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::SlaveID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::SlaveID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Offer->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Offer',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::OfferID', 
                    'id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::FrameworkID', 
                    'framework_id', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::SlaveID', 
                    'slave_id', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'hostname', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Resource', 
                    'resources', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::ExecutorID', 
                    'executor_ids', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Attribute', 
                    'attributes', 7, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ExecutorInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ExecutorInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ExecutorID', 
                    'executor_id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BYTES(), 
                    'data', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Resource', 
                    'resources', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::CommandInfo', 
                    'command', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::FrameworkID', 
                    'framework_id', 8, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 9, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'source', 10, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ContainerInfo', 
                    'container', 11, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::CommandInfo::ContainerInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::CommandInfo::ContainerInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'image', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'options', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Filters->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Filters',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'refuse_seconds', 1, 5.0
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Resource->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Resource',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::Value::Type', 
                    'type', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Scalar', 
                    'scalar', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Ranges', 
                    'ranges', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Set', 
                    'set', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'role', 6, "*"
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value::Ranges->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value::Ranges',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Value::Range', 
                    'range', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::MasterInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::MasterInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'ip', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'port', 3, 5050
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'pid', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'hostname', 5, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Environment->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Environment',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Environment::Variable', 
                    'variables', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Parameters->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Parameters',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Parameter', 
                    'parameter', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACL::Entity->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACL::Entity',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ACL::Entity::Type', 
                    'type', 1, 0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'values', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::PerfStatistics->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::PerfStatistics',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'timestamp', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'duration', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'cycles', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'stalled_cycles_frontend', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'stalled_cycles_backend', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'instructions', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'cache_references', 7, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'cache_misses', 8, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'branches', 9, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'branch_misses', 10, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'bus_cycles', 11, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'ref_cycles', 12, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'cpu_clock', 13, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'task_clock', 14, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'page_faults', 15, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'minor_faults', 16, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'major_faults', 17, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'context_switches', 18, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'cpu_migrations', 19, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'alignment_faults', 20, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'emulation_faults', 21, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_loads', 22, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_load_misses', 23, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_stores', 24, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_store_misses', 25, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_prefetches', 26, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_dcache_prefetch_misses', 27, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_icache_loads', 28, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_icache_load_misses', 29, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_icache_prefetches', 30, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'l1_icache_prefetch_misses', 31, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_loads', 32, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_load_misses', 33, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_stores', 34, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_store_misses', 35, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_prefetches', 36, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'llc_prefetch_misses', 37, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_loads', 38, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_load_misses', 39, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_stores', 40, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_store_misses', 41, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_prefetches', 42, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'dtlb_prefetch_misses', 43, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'itlb_loads', 44, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'itlb_load_misses', 45, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'branch_loads', 46, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'branch_load_misses', 47, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_loads', 48, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_load_misses', 49, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_stores', 50, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_store_misses', 51, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_prefetches', 52, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'node_prefetch_misses', 53, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::HealthCheck::HTTP->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::HealthCheck::HTTP',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'port', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'path', 2, "/"
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'statuses', 4, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::Value::Type', 
                    'type', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Scalar', 
                    'scalar', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Ranges', 
                    'ranges', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Set', 
                    'set', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Text', 
                    'text', 5, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACL::RunTask->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACL::RunTask',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'principals', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::ACL::Entity', 
                    'users', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::SlaveInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::SlaveInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'hostname', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'webui_hostname', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Resource', 
                    'resources', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_INT32(), 
                    'webui_port', 4, 8081
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Attribute', 
                    'attributes', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::SlaveID', 
                    'id', 6, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'checkpoint', 7, 0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_INT32(), 
                    'port', 8, 5051
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Request->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Request',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::SlaveID', 
                    'slave_id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::Resource', 
                    'resources', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value::Text->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value::Text',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ResourceUsage->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ResourceUsage',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::SlaveID', 
                    'slave_id', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::FrameworkID', 
                    'framework_id', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ExecutorID', 
                    'executor_id', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'executor_name', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::TaskID', 
                    'task_id', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::ResourceStatistics', 
                    'statistics', 6, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Value::Range->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Value::Range',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'begin', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT64(), 
                    'end', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Attribute->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Attribute',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'name', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::Value::Type', 
                    'type', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Scalar', 
                    'scalar', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Ranges', 
                    'ranges', 4, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Text', 
                    'text', 5, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::Value::Set', 
                    'set', 6, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::HealthCheck->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::HealthCheck',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::HealthCheck::HTTP', 
                    'http', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'delay_seconds', 2, 15.0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'interval_seconds', 3, 10.0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'timeout_seconds', 4, 20.0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_UINT32(), 
                    'consecutive_failures', 5, 3
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_DOUBLE(), 
                    'grace_period_seconds', 6, 10.0
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    'Mesos::CommandInfo', 
                    'command', 7, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Volume->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Volume',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'container_path', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'host_path', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    'Mesos::Volume::Mode', 
                    'mode', 3, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ACLs->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ACLs',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_OPTIONAL(), 
                    Google::ProtocolBuffers::Constants::TYPE_BOOL(), 
                    'permissive', 1, 1
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::ACL::RegisterFramework', 
                    'register_frameworks', 2, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::ACL::RunTask', 
                    'run_tasks', 3, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REPEATED(), 
                    'Mesos::ACL::ShutdownFramework', 
                    'shutdown_frameworks', 4, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::ContainerInfo::DockerInfo->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::ContainerInfo::DockerInfo',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'image', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::Parameter->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::Parameter',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'key', 1, undef
                ],
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 2, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

    unless (Mesos::OfferID->can('_pb_fields_list')) {
        Google::ProtocolBuffers->create_message(
            'Mesos::OfferID',
            [
                [
                    Google::ProtocolBuffers::Constants::LABEL_REQUIRED(), 
                    Google::ProtocolBuffers::Constants::TYPE_STRING(), 
                    'value', 1, undef
                ],

            ],
            { 'create_accessors' => 1,  }
        );
    }

}
1;
